Notifiable

Trait Notifiable 

pub trait Notifiable: Debug {
    // Required method
    fn to_msg(&self) -> impl AsRef<str>;
}
Types that can be converted to a notification message for Nvim.

Implementors provide a way to transform themselves into a string suitable for display in Nvim notifications.

Required Methods

fn to_msg(&self) -> impl AsRef<str>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Notifiable for &str

Source

fn to_msg(&self) -> impl AsRef<str>

Source

impl Notifiable for Report

Source

fn to_msg(&self) -> impl AsRef<str>

Source

impl Notifiable for String

Source

fn to_msg(&self) -> impl AsRef<str>

Source

impl<T: Notifiable + ?Sized> Notifiable for &T

Source

fn to_msg(&self) -> impl AsRef<str>

Implementors