pub trait Notifiable: Debug {
// Required method
fn to_msg(&self) -> impl AsRef<str>;
}Expand description
Types that can be converted to a notification message for Nvim.
Implementors provide a way to transform themselves into a string suitable for display in Nvim notifications.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".